pub struct ImageRef<'a> { /* private fields */ }Expand description
A handle to a single frame for read-only access.
Each accessor pins the wand’s iterator to this frame and then reads, so the
returned values always correspond to this frame regardless of what other
frames are touched in between. Unlike ImageMut, this handle deliberately
does not deref to MagickWand: doing so would both expose the wand’s
image-mutating methods (defeating the read-only contract) and hand out a
&MagickWand that silently goes stale once another frame is accessed.
Implementations
Sourceimpl ImageRef<'_>
impl ImageRef<'_>
Sourcepub fn get_image_width(&self) -> usize
pub fn get_image_width(&self) -> usize
Read this frame’s value; see MagickWand::get_image_width.
Sourcepub fn get_image_height(&self) -> usize
pub fn get_image_height(&self) -> usize
Read this frame’s value; see MagickWand::get_image_height.
Sourcepub fn get_image_page(&self) -> (usize, usize, isize, isize)
pub fn get_image_page(&self) -> (usize, usize, isize, isize)
Read this frame’s value; see MagickWand::get_image_page.
Sourcepub fn get_image_resolution(&self) -> Result<(f64, f64), MagickError>
pub fn get_image_resolution(&self) -> Result<(f64, f64), MagickError>
Read this frame’s value; see MagickWand::get_image_resolution.
Sourcepub fn get_image_range(&self) -> Result<(f64, f64), MagickError>
pub fn get_image_range(&self) -> Result<(f64, f64), MagickError>
Read this frame’s value; see MagickWand::get_image_range.
Sourcepub fn get_image_colors(&self) -> usize
pub fn get_image_colors(&self) -> usize
Read this frame’s value; see MagickWand::get_image_colors.
Sourcepub fn get_image_alpha_channel(&self) -> bool
pub fn get_image_alpha_channel(&self) -> bool
Read this frame’s value; see MagickWand::get_image_alpha_channel.
Sourcepub fn get_image_virtual_pixel_method(&self) -> VirtualPixelMethod
pub fn get_image_virtual_pixel_method(&self) -> VirtualPixelMethod
Read this frame’s value; see MagickWand::get_image_virtual_pixel_method.
Sourcepub fn get_image_pixel_color(&self, x: isize, y: isize) -> Option<PixelWand>
pub fn get_image_pixel_color(&self, x: isize, y: isize) -> Option<PixelWand>
Read this frame’s value; see MagickWand::get_image_pixel_color.
Sourcepub fn get_image_histogram(&self) -> Option<Vec<PixelWand>>
pub fn get_image_histogram(&self) -> Option<Vec<PixelWand>>
Read this frame’s value; see MagickWand::get_image_histogram.
Sourcepub fn get_image_artifact(&self, artifact: &str) -> Result<String, MagickError>
pub fn get_image_artifact(&self, artifact: &str) -> Result<String, MagickError>
Read this frame’s value; see MagickWand::get_image_artifact.
Sourcepub fn get_image_artifacts(
&self,
pattern: &str,
) -> Result<Vec<String>, MagickError>
pub fn get_image_artifacts( &self, pattern: &str, ) -> Result<Vec<String>, MagickError>
Read this frame’s value; see MagickWand::get_image_artifacts.
Sourcepub fn get_image_property(&self, name: &str) -> Result<String, MagickError>
pub fn get_image_property(&self, name: &str) -> Result<String, MagickError>
Read this frame’s value; see MagickWand::get_image_property.
Sourcepub fn get_image_properties(
&self,
pattern: &str,
) -> Result<Vec<String>, MagickError>
pub fn get_image_properties( &self, pattern: &str, ) -> Result<Vec<String>, MagickError>
Read this frame’s value; see MagickWand::get_image_properties.
Sourcepub fn get_image_format(&self) -> Result<String, MagickError>
pub fn get_image_format(&self) -> Result<String, MagickError>
Read this frame’s value; see MagickWand::get_image_format.
Sourcepub fn get_image_filename(&self) -> Result<String, MagickError>
pub fn get_image_filename(&self) -> Result<String, MagickError>
Read this frame’s value; see MagickWand::get_image_filename.
Sourcepub fn get_image_compose(&self) -> CompositeOperator
pub fn get_image_compose(&self) -> CompositeOperator
Read this frame’s value; see MagickWand::get_image_compose.
Sourcepub fn get_image_colorspace(&self) -> ColorspaceType
pub fn get_image_colorspace(&self) -> ColorspaceType
Read this frame’s value; see MagickWand::get_image_colorspace.
Sourcepub fn get_image_compression(&self) -> CompressionType
pub fn get_image_compression(&self) -> CompressionType
Read this frame’s value; see MagickWand::get_image_compression.
Sourcepub fn get_image_compression_quality(&self) -> usize
pub fn get_image_compression_quality(&self) -> usize
Read this frame’s value; see MagickWand::get_image_compression_quality.
Sourcepub fn get_image_delay(&self) -> usize
pub fn get_image_delay(&self) -> usize
Read this frame’s value; see MagickWand::get_image_delay.
Sourcepub fn get_image_depth(&self) -> usize
pub fn get_image_depth(&self) -> usize
Read this frame’s value; see MagickWand::get_image_depth.
Sourcepub fn get_image_dispose(&self) -> DisposeType
pub fn get_image_dispose(&self) -> DisposeType
Read this frame’s value; see MagickWand::get_image_dispose.
Sourcepub fn get_image_endian(&self) -> EndianType
pub fn get_image_endian(&self) -> EndianType
Read this frame’s value; see MagickWand::get_image_endian.
Sourcepub fn get_image_fuzz(&self) -> f64
pub fn get_image_fuzz(&self) -> f64
Read this frame’s value; see MagickWand::get_image_fuzz.
Sourcepub fn get_image_gamma(&self) -> f64
pub fn get_image_gamma(&self) -> f64
Read this frame’s value; see MagickWand::get_image_gamma.
Sourcepub fn get_image_gravity(&self) -> GravityType
pub fn get_image_gravity(&self) -> GravityType
Read this frame’s value; see MagickWand::get_image_gravity.
Sourcepub fn get_image_interlace_scheme(&self) -> InterlaceType
pub fn get_image_interlace_scheme(&self) -> InterlaceType
Read this frame’s value; see MagickWand::get_image_interlace_scheme.
Sourcepub fn get_image_interpolate_method(&self) -> PixelInterpolateMethod
pub fn get_image_interpolate_method(&self) -> PixelInterpolateMethod
Read this frame’s value; see MagickWand::get_image_interpolate_method.
Sourcepub fn get_image_iterations(&self) -> usize
pub fn get_image_iterations(&self) -> usize
Read this frame’s value; see MagickWand::get_image_iterations.
Sourcepub fn get_image_orientation(&self) -> OrientationType
pub fn get_image_orientation(&self) -> OrientationType
Read this frame’s value; see MagickWand::get_image_orientation.
Sourcepub fn get_image_rendering_intent(&self) -> RenderingIntent
pub fn get_image_rendering_intent(&self) -> RenderingIntent
Read this frame’s value; see MagickWand::get_image_rendering_intent.
Sourcepub fn get_image_scene(&self) -> usize
pub fn get_image_scene(&self) -> usize
Read this frame’s value; see MagickWand::get_image_scene.
Sourcepub fn get_image_type(&self) -> ImageType
pub fn get_image_type(&self) -> ImageType
Read this frame’s value; see MagickWand::get_image_type.
Sourcepub fn get_image_units(&self) -> ResolutionType
pub fn get_image_units(&self) -> ResolutionType
Read this frame’s value; see MagickWand::get_image_units.
Sourceimpl ImageRef<'_>
impl ImageRef<'_>
Sourcepub fn get_image(&self) -> Result<Image<'_>, MagickError>
pub fn get_image(&self) -> Result<Image<'_>, MagickError>
Borrow this frame as an Image, e.g. for MagickWand::new_from_image.
The returned Image captures this frame’s underlying image pointer, so
it remains valid even if the wand’s iterator is later moved to another
frame.